surv_uni_con: Modify the Survival Output for a Continuous Variable.
Description
This function generates a table with the general survival analysis results, including the number of total patients, the number of events, the P value, the AIC, and the C index. This function just modifies the output table's format.